@@ -1028,8 +1028,8 @@ class TestNetworkElement(unittest.TestCase):
         }
 
         ne = self._await(self.reg.set('TestNE', {'name': 'Test Element', 'site': 'My Site'}))
-        ne.cfg = cfg
         ne.device = FakeDevice(None)
+        ne.device.cfg = cfg
         ne.network_element_update_msg = NetworkElementUpdate()
         ne.network_element_update_msg.data = NetworkElement(errctx=ErrorContext())
 
